<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Mapa de Ruta Clientes</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/css/bootstrap.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://unpkg.com/leaflet/dist/leaflet.css" />
    <style>
        #map {
            height: 600px;
            width: 100%;
        }
    </style>
</head>
<body>
    <div class="container mt-4">
        <div class="row">
            <div class="col-md-4">
                <label for="vendedorSelect" class="form-label">Seleccione Vendedor</label>
                <select class="form-select" id="vendedorSelect">
                      <option value="" disabled selected>Seleccione un vendedor</option>
  					  <option value="VEN003">JUAN GOMEZ BORBOR</option>
						<option value="VEN099">Ventas de Oficina</option>
                </select>
            </div>
            <div class="col-md-2">
                <label class="form-label">&nbsp;</label>
                <button id="buscarBtn" class="btn btn-primary w-100">Buscar</button>
            </div>
        </div>
        <div class="row mt-4">
            <div id="map"></div>
        </div>
    </div>

    <script src="https://unpkg.com/leaflet/dist/leaflet.js"></script>
    <script>
		
        const map = L.map('map').setView([0, 0], 2);

        L.tileLayer('https://{s}.tile.openstreetmap.org/{z}/{x}/{y}.png', {
            attribution: '&copy; OpenStreetMap contributors'
        }).addTo(map);

       	document.getElementById('buscarBtn').addEventListener('click', function() {			
		const vendedor = document.getElementById('vendedorSelect').value;

		fetch('getClientes.php?vendedor=' + vendedor)
			.then(response => {
				if (!response.ok) {
					throw new Error('Error en la respuesta del servidor');
				}
				return response.text(); // Cambiar a response.text() para ver la salida como texto
			})
			.then(data => {
				//console.log(data); // Imprimir la respuesta completa para ver si es un JSON válido
				alert(data);
				// Intenta convertir la respuesta a JSON manualmente para detectar problemas
				try {
					const jsonData = JSON.parse(data); // Intentar convertir manualmente a JSON
					console.log(jsonData); // Si es válido, imprimir el JSON
					if (jsonData.message) {
						alert(jsonData.message);
						return;
					}

					map.setView([jsonData[0].latitud, jsonData[0].longitud], 10);

					jsonData.forEach(cliente => {
						const marker = L.marker([cliente.latitud, cliente.longitud], {
							icon: L.icon({
								iconUrl: 'https://image.flaticon.com/icons/png/512/69/69524.png',
								iconSize: [32, 32],
								iconAnchor: [16, 32]
							})
						}).addTo(map);

						marker.bindPopup(`
							<strong>${cliente.codigo} - ${cliente.nombre}</strong><br>
							Dirección: ${cliente.direccion}
						`);
					});
				} catch (error) {
					console.error('No se pudo convertir a JSON:', error);
					alert('Error al procesar la respuesta del servidor.');
				}
			})
			.catch(error => {
				console.error('Error al obtener los datos:', error);
			});
		});




    </script>
</body>
</html>
